AssetDiscoveryService class

Service responsible for discovering asset files based on configuration

Constructors

AssetDiscoveryService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

discoverFiles(ConfigEntry entry, String workingDirectory) Future<List<FileConfig>>
Discover files based on a configuration entry
shouldExcludeFile(String fileName, String filePath, List<String> exclusions) bool
Check if a file should be excluded based on exclusion patterns
validateGenerators(Config config) → void
Validate that all configuration entries have valid generators