CodeGenerationService class

Service responsible for generating Dart code from discovered assets

Constructors

CodeGenerationService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateDartCode({String? lockPath, String? configPath, String? workingDirectory}) Future<String>
Generate Dart code from lock file