typeRegistry property
Type registry for mapping file types to asset types
Implementation
@JsonKey(name: 'type_registry')
final Map<String, TypeConfig>? typeRegistry;
Type registry for mapping file types to asset types
@JsonKey(name: 'type_registry')
final Map<String, TypeConfig>? typeRegistry;