CacheConfig class

Cache configuration for AssetX processing

Annotations
  • @JsonSerializable.new()

Constructors

CacheConfig({bool? memory, String? src})
const
CacheConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
memory bool?
Whether to use memory caching
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String?
Source file for cache implementation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited