MapConfig class

Map configuration for mapping asset types to implementation classes

Annotations
  • @JsonSerializable.new()

Constructors

MapConfig({String? builtin, String? src, String? passIn, bool lazy = true})
const
MapConfig.fromJson(Map<String, dynamic> json)
factory

Properties

builtin String?
Built-in type name (e.g., 'imagex', 'datax', 'envx')
final
hashCode int
The hash code for this object.
no setterinherited
lazy bool
final
passIn String?
Parameter passing mode for custom implementations Values: 'path', 'json', etc.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src String?
Source file and class for custom implementations Format: "lib/file.dart::ClassName" or "lib/file.dart::ClassName.method"
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited