TypeConfig class

Type configuration for mapping file extensions or patterns to asset types

Annotations
  • @JsonSerializable.new()

Constructors

TypeConfig({List<String>? fileExtensions, List<String>? pattern})
const
TypeConfig.fromJson(Map<String, dynamic> json)
factory

Properties

fileExtensions List<String>?
File extensions associated with this type
final
hashCode int
The hash code for this object.
no setterinherited
pattern List<String>?
Patterns for matching files to this type
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited