TemplateProcessor class

Utility methods for code generation using AssetLookup objects

Constructors

TemplateProcessor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateFile(List<AssetLookupFile> files, List<AssetLookupFolder> folders, AssetXConfig config, String packageName, {bool usePackagePrefix = true}) String
Generates the complete file content from AssetLookup objects