StaticGenerator class

Utility class for generating static non-lazy classes for datax and envx types

Constructors

StaticGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

findNonLazyFiles(List<AssetLookupFile> files, AssetXConfig config) List<AssetLookupFile>
Finds files that should be generated as non-lazy static classes
generateNonLazyClasses(CodeBuffer buffer, List<AssetLookupFile> files, AssetXConfig config, String packageName, bool usePackagePrefix) → void
Generates non-lazy static classes for datax and envx types