BaseGenerator class abstract

Implementers

Constructors

BaseGenerator()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requiresPubspecAsset bool
Whether assets generated by this generator need to be declared in pubspec.yaml Should be true for soft loading types that use Flutter's asset system
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedExtensions List<String>
no setter

Methods

canHandle(String extension) bool
generateAccessors(List<FileConfig> fileCfgs) List<FileAccessor>
Generate structured accessor information for files
generateCode(List<FileConfig> fileCfgs) GenerationResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited