requiresPubspecAsset property

bool get requiresPubspecAsset

Whether assets generated by this generator need to be declared in pubspec.yaml Should be true for soft loading types that use Flutter's asset system

Implementation

bool get requiresPubspecAsset => false;