GeneratorRegistry class

Generator registry for managing builtin and custom generators

Constructors

GeneratorRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

canHandleFile(String type, String filePath) bool
Check if a generator can handle a specific file extension for the given type
getGenerator(String type) BaseGenerator?
Get generator for a specific type
getRegisteredTypes() List<String>
Get all registered generator types
hasGenerator(String type) bool
Check if a generator exists for the given type
registerGenerator(String type, BaseGenerator generator) → void
Register a new generator