ImageHardGenerator class

Generator for hardcode image assets (embedded as base64)

Inheritance

Constructors

ImageHardGenerator()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requiresPubspecAsset bool
Whether assets generated by this generator need to be declared in pubspec.yaml Should be true for soft loading types that use Flutter's asset system
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedExtensions List<String>
no setteroverride

Methods

canHandle(String extension) bool
inherited
generateAccessors(List<FileConfig> fileCfgs) List<FileAccessor>
Generate structured accessor information for files
inherited
generateCode(List<FileConfig> fileCfgs) GenerationResult
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited