ConfigEntry class
Constructors
-
ConfigEntry({required String path, required String type, List<
String> exclusions = const [], bool recursive = false}) -
ConfigEntry.fromYaml(Map<
String, dynamic> yaml) -
factory
Properties
- baseType → String
-
Get the base asset category (image, kv, etc.)
no setter
-
exclusions
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isHardcode → bool
-
Check if this entry is for hardcode (embedded) assets
no setter
- isSoft → bool
-
Check if this entry is for soft (asset loading) assets
no setter
- path → String
-
final
- recursive → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toYaml(
) → Map< String, dynamic>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited