FileConfig class

Constructors

FileConfig(String fullPath, String type, String uid)
FileConfig.fromJson(Map<String, dynamic> json)
factory
FileConfig.generate(String fullPath, String type)
Create a FileConfig with auto-generated UID
factory

Properties

fullPath String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
uid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateWithCollisionHandling(List<({String path, String type})> inputs) List<FileConfig>
Generate UIDs with collision resolution
hasCollisions(List<FileConfig> configs) bool
Check for UID collisions in a list of FileConfigs