LockFile class

Constructors

LockFile(List<FileConfig> files)
LockFile.fromJson(Map<String, dynamic> json)
factory

Properties

files List<FileConfig>
final
hasCollisions bool
Check if this lock file has UID collisions
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findByUID(String uid) FileConfig?
Get FileConfig by UID
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(String lockPath) Future<void>
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load(String lockPath) Future<LockFile>