BaseX class

Implementers

Constructors

BaseX(String path, {bool lazy = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lazy bool
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

getCacheMethod Function
getter/setter pair
setCacheMethod Function
getter/setter pair