DataX class

Inheritance

Constructors

DataX(String path)

Properties

asset Future<Map<String, dynamic>>
no setter
hashCode int
The hash code for this object.
no setterinherited
lazy bool
finalinherited
path String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](String key) → dynamic