menu
assetx package
documentation
objectx/folderx.dart
FolderX class
FolderX class
dark_mode
light_mode
FolderX
class
Inheritance
Object
BaseX
FolderX
Constructors
FolderX
(
String
path
)
const
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
lazy
→
bool
final
inherited
path
→
String
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
asset
<
T
>
(
String
fileName
)
→ T
assetPath
(
String
fileName
)
→
String
hasFile
(
String
fileName
)
→
bool
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
assetx package
documentation
objectx/folderx
FolderX class
folderx library