CodeBuffer class
Constructors
Properties
- codeBody → StringBuffer
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
importLines
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addCode(
String code) → void -
addImport(
String importLine) → void -
generate(
) → String -
merge(
CodeBuffer other) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited