PackagePathUtils class

Utility functions for generating Flutter package asset paths

Constructors

PackagePathUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCurrentPackageName() String?
Gets the current package name from pubspec.yaml
getPackageAssetPath(String relativePath) String
Converts a relative asset path to Flutter package path format Returns packages/{packageName}/{path} for cross-package loading