AssetLookupFile class

Inheritance
Available extensions

Constructors

AssetLookupFile(String path, AssetLookupFolder? parent)

Properties

basename String
no setter
dotPath String

Available on AssetLookupFile, provided by the AssetLookupFileCodeGen extension

Converts file path to dot notation "assets/data/config.json" -> "assets.data.config" (without extension)
no setter
dotPathWithExtension String

Available on AssetLookupFile, provided by the AssetLookupFileCodeGen extension

Converts file path to dot notation with extension for disambiguation "assets/data/config.json" -> "assets.data.config_json"
no setter
extension String
no setter
hashCode int
The hash code for this object.
no setterinherited
normalizedPath String
Returns the path with normalized separators (forward slashes)
no setterinherited
parent AssetLookupFolder?
final
path String
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAssetType(AssetXConfig config) String

Available on AssetLookupFile, provided by the AssetLookupFileCodeGen extension

Determines asset type based on config
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited