AssetLookupFolder class

Inheritance
Available extensions

Constructors

AssetLookupFolder(String path, AssetLookupFolder? parent, bool fullyIndexed)

Properties

childFiles List<AssetLookupFile>

Available on AssetLookupFolder, provided by the AssetLookupFolderCodeGen extension

Gets child files as AssetLookupFile objects
no setter
childFolders List<AssetLookupFolder>

Available on AssetLookupFolder, provided by the AssetLookupFolderCodeGen extension

Gets child folders as AssetLookupFolder objects
no setter
children List<AssetLookup>
final
dotPath String

Available on AssetLookupFolder, provided by the AssetLookupFolderCodeGen extension

Converts folder path to dot notation "assets/data" -> "assets.data"
no setter
folderName String

Available on AssetLookupFolder, provided by the AssetLookupFolderCodeGen extension

Gets folder name for display
no setter
fullyIndexed bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
normalizedPath String
Returns the path with normalized separators (forward slashes)
no setterinherited
parent AssetLookupFolder?
final
path String
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateClassName(int counter) String

Available on AssetLookupFolder, provided by the AssetLookupFolderCodeGen extension

Generates unique class name for this folder
generateInstanceName(String className) String

Available on AssetLookupFolder, provided by the AssetLookupFolderCodeGen extension

Generates instance name from class name
getPubspecAssetPaths() List<String>
Generates a list of pubspec asset paths based on folder indexing rules
getTreeString({String indent = '', bool isLast = true, bool showFiles = true, int? maxDepth, int currentDepth = 0}) String
Returns a string representation of the tree structure
iterSub({bool folders = true, bool files = true, List<String> patterns = const []}) Iterable<AssetLookup>
Iterates through all AssetLookup objects in this folder and its subfolders
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printTree({String indent = '', bool isLast = true, bool showFiles = true, int? maxDepth, int currentDepth = 0, List<AssetLookupFile>? validFiles}) → void
Prints a pretty tree structure of this folder and its children
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited