AssetXService class
Main AssetX service that orchestrates asset operations This class provides a unified API while delegating to specialized core services
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateDartCode(
{String? lockPath, String? configPath, String? workingDirectory}) → Future< String> - Generate Dart code from lock file
-
generateLock(
{String? configPath, String? lockPath, String? workingDirectory}) → Future< void> - Generate lock file from configuration
-
getLockedFiles(
[String? lockPath]) → Future< List< FileConfig> > - Get files from existing lock file
-
isLockUpToDate(
{String? configPath, String? lockPath}) → Future< bool> - Check if lock file exists and is up to date
Constants
- defaultConfigFile → const String
- defaultLockFile → const String