AssetXConfig class
Root configuration class for AssetX configuration files.
This class represents the complete structure of an AssetX configuration file, typically parsed from YAML using YamlUtils.parseYamlToJson().
Example usage:
final yamlContent = await File('assetx.yaml').readAsString();
final jsonMap = YamlUtils.parseYamlToJson(yamlContent);
final config = AssetXConfig.fromJson(jsonMap);
- Annotations
-
- @JsonSerializable.new()
Constructors
-
AssetXConfig({required String destination, String? localDestination, CacheConfig? cache, List<
SourceConfig> ? sourcesInclude, List<SourceConfig> ? sourcesExclude, List<String> ? patternsInclude, List<String> ? patternsExclude, Map<String, TypeConfig> ? typeRegistry, Map<String, MapConfig> ? mapRegistry}) -
const
-
AssetXConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- cache → CacheConfig?
-
Cache configuration settings
final
- destination → String
-
Output file destination for generated code
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localDestination → String?
-
Local output file destination for testing (without package prefixes)
final
-
mapRegistry
→ Map<
String, MapConfig> ? -
Map registry for mapping asset types to implementation classes
final
-
patternsExclude
→ List<
String> ? -
File patterns to exclude (glob patterns)
final
-
patternsInclude
→ List<
String> ? -
File patterns to include (glob patterns)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourcesExclude
→ List<
SourceConfig> ? -
Source paths to exclude from asset processing
final
-
sourcesInclude
→ List<
SourceConfig> ? -
Source paths to include for asset processing
final
-
typeRegistry
→ Map<
String, TypeConfig> ? -
Type registry for mapping file types to asset types
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited