SourceConfig class
Source path configuration for asset inclusion/exclusion
- Annotations
-
- @JsonSerializable.new()
Constructors
-
SourceConfig({required String path, bool? recursive, List<
String> ? ignore}) -
const
-
SourceConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ignore
→ List<
String> ? -
Patterns to ignore within this source path
final
- path → String
-
Path to the source directory or file
final
- recursive → bool?
-
Whether to process the path recursively
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited