FileAccessor class
Information about how to access a file in generated code
Constructors
- FileAccessor({required String assetName, required String accessorCode, required String filePathAccessor})
Properties
- accessorCode → String
-
final
- assetName → String
-
final
- filePathAccessor → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited