Config class
Constructors
-
Config(List<
ConfigEntry> entries, {String generationTarget = 'lib/asset.dart'})
Properties
-
entries
→ List<
ConfigEntry> -
final
- generationTarget → String
-
final
-
hardcodeEntries
→ List<
ConfigEntry> -
Get all entries with hardcode types
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
softEntries
→ List<
ConfigEntry> -
Get all entries with soft types
no setter
Methods
-
getEntriesByBaseType(
String baseType) → List< ConfigEntry> - Get entries by base type (e.g., 'image', 'kv')
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
String configPath) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void - Validate configuration for common issues
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited