IdentifierUtils class
Utility functions for identifier generation and validation
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createFolderKey(
String folderPath) → String - Generate a unique key for grouping files by folder path
-
createUniqueClassName(
String folderPath) → String - Generate a unique hash-based class name for folder paths to prevent naming conflicts
-
createValidClassName(
String name) → String - Creates a PascalCase class name from a given name
-
createValidIdentifier(
String name) → String - Creates a valid Dart identifier from a given name