AssetDiscoveryResult class
Result of asset discovery containing all found files and folders
Constructors
-
AssetDiscoveryResult(List<
AssetLookupFile> files, List<AssetLookupFolder> folders, bool wasFiltered) -
const
Properties
-
files
→ List<
AssetLookupFile> -
final
-
folders
→ List<
AssetLookupFolder> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wasFiltered → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited